@@ -1,5 +1,6 @@
-import threading
 import re
+import threading
+
 from bs4 import BeautifulSoup
 from requests import get
 
@@ -13,9 +14,9 @@ def author_researches(author_id, output_format='dictionary', pretty_print=None,
     page_info = soup.select('.uk-width-large-1-2.table-footer')
     n_page = int(page_info[0].text.strip().split()[3])
     threads = []
-    worker_result = []
+    worker_result = parse(soup)
 
-    for page in range(1, n_page + 1):
+    for page in range(2, n_page + 1):
         thread = threading.Thread(target=worker, args=(author_id, page, worker_result))
 
         thread.start()
@@ -28,30 +29,39 @@ def author_researches(author_id, output_format='dictionary', pretty_print=None,
 
 
 def worker(author_id, page, worker_result):
-    page_url = f'http://sinta.ristekbrin.go.id/authors/detail?page={page}&id={author_id}&view=research'
-    page_html = get(page_url)
-    page_soup = BeautifulSoup(page_html.content, 'html.parser')
-    trs = page_soup.select('table.uk-table tr')
+    url = f'http://sinta.ristekbrin.go.id/authors/detail?page={page}&id={author_id}&view=research'
+    html = get(url)
+    soup = BeautifulSoup(html.content, 'html.parser')
+    data = parse(soup)
 
-    for tr in trs:
-        link = tr.select('a.paper-link')
+    worker_result.extend(data)
+
+
+def parse(soup):
+    rows = soup.select('table.uk-table tr')
+    result = []
+
+    for row in rows:
+        link = row.select('a.paper-link')
 
         if not link:
             continue
 
         link = link[0]
-        info1 = tr.select('dd.indexed-by-orange')[0].text.strip().split('|')
-        dd = tr.select('dd')
+        info1 = row.select('dd.indexed-by-orange')[0].text.strip().split('|')
+        dd = row.select('dd')
         info2 = [i.strip().split(':')[1].strip() for i in dd[2].text.strip().split('\r\n')]
         members = [member.strip() for member in dd[1].text.split(',') if member.strip()]
 
-        worker_result.append({
+        result.append({
             'title': link.text.strip(),
             'scheme': info1[0].split(':')[1].strip(),
             'source': info1[1].split(':')[1].strip(),
             'members': members,
             'application_year': int(info2[0]),
             'event_year': int(info2[1]),
-            'fund': int(re.sub('[Rp\.\s\,]', '', info2[2])[:-2]),
+            'fund': int(re.sub(r'[Rp\.\s\,]', '', info2[2])[:-2]),
             'field': dd[3].text.strip()
         })
+
+    return result
